@@ -19,29 +19,33 @@
 //  Email:
 //    mhadji@gmail.com
 
-#include "../spatialindex/SpatialIndexImpl.h"
+#include <limits>
+
+#include <spatialindex/SpatialIndex.h>
+
 #include "MVRTree.h"
 #include "Node.h"
 #include "Leaf.h"
 #include "Index.h"
 
+using namespace SpatialIndex;
 using namespace SpatialIndex::MVRTree;
 
 Index::~Index()
 {
 }
 
-Index::Index(SpatialIndex::MVRTree::MVRTree* pTree, id_type id, size_t level) : Node(pTree, id, level, pTree->m_indexCapacity)
+Index::Index(SpatialIndex::MVRTree::MVRTree* pTree, id_type id, uint32_t level) : Node(pTree, id, level, pTree->m_indexCapacity)
 {
 }
 
-NodePtr Index::chooseSubtree(const TimeRegion& mbr, size_t insertionLevel, std::stack<id_type>& pathBuffer)
+NodePtr Index::chooseSubtree(const TimeRegion& mbr, uint32_t insertionLevel, std::stack<id_type>& pathBuffer)
 {
 	if (m_level == insertionLevel) return NodePtr(this, &(m_pTree->m_indexPool));
 
 	pathBuffer.push(m_identifier);
 
-	size_t child = 0;
+	uint32_t child = 0;
 
 	switch (m_pTree->m_treeVariant)
 	{
@@ -63,7 +67,7 @@ NodePtr Index::chooseSubtree(const TimeRegion& mbr, size_t insertionLevel, std::
 		default:
 			throw Tools::NotSupportedException("Index::chooseSubtree: Tree variant not supported.");
 	}
-	assert (child != std::numeric_limits<size_t>::max());
+	assert (child != std::numeric_limits<uint32_t>::max());
 
 	NodePtr n = m_pTree->readNode(m_pIdentifier[child]);
 	NodePtr ret = n->chooseSubtree(mbr, insertionLevel, pathBuffer);
@@ -77,7 +81,7 @@ NodePtr Index::findLeaf(const TimeRegion& mbr, id_type id, std::stack<id_type>&
 {
 	pathBuffer.push(m_identifier);
 
-	for (size_t cChild = 0; cChild < m_children; cChild++)
+	for (uint32_t cChild = 0; cChild < m_children; ++cChild)
 	{
 		// check live nodes only.
 		if (m_ptrMBR[cChild]->m_endTime < std::numeric_limits<double>::max()) continue;
@@ -99,12 +103,12 @@ NodePtr Index::findLeaf(const TimeRegion& mbr, id_type id, std::stack<id_type>&
 }
 
 void Index::split(
-	size_t dataLength, byte* pData, TimeRegion& mbr, id_type id, NodePtr& pLeft, NodePtr& pRight,
+	uint32_t dataLength, byte* pData, TimeRegion& mbr, id_type id, NodePtr& pLeft, NodePtr& pRight,
 	TimeRegion& mbr2, id_type id2, bool bInsertMbr2)
 {
-	m_pTree->m_stats.m_splits++;
+	++(m_pTree->m_stats.m_u64Splits);
 
-	std::vector<size_t> g1, g2;
+	std::vector<uint32_t> g1, g2;
 
 	switch (m_pTree->m_treeVariant)
 	{
@@ -128,27 +132,27 @@ void Index::split(
 	pLeft->m_nodeMBR = m_pTree->m_infiniteRegion;
 	pRight->m_nodeMBR = m_pTree->m_infiniteRegion;
 
-	size_t cIndex;
+	uint32_t cIndex;
 
-	for (cIndex = 0; cIndex < g1.size(); cIndex++)
+	for (cIndex = 0; cIndex < g1.size(); ++cIndex)
 	{
 		pLeft->insertEntry(0, 0, *(m_ptrMBR[g1[cIndex]]), m_pIdentifier[g1[cIndex]]);
 	}
 
-	for (cIndex = 0; cIndex < g2.size(); cIndex++)
+	for (cIndex = 0; cIndex < g2.size(); ++cIndex)
 	{
 		pRight->insertEntry(0, 0, *(m_ptrMBR[g2[cIndex]]), m_pIdentifier[g2[cIndex]]);
 	}
 }
 
-size_t Index::findLeastEnlargement(const TimeRegion& r) const
+uint32_t Index::findLeastEnlargement(const TimeRegion& r) const
 {
 	double area = std::numeric_limits<double>::max();
-	size_t best = std::numeric_limits<size_t>::max();
+	uint32_t best = std::numeric_limits<uint32_t>::max();
 
 	TimeRegionPtr t = m_pTree->m_regionPool.acquire();
 
-	for (size_t cChild = 0; cChild < m_children; cChild++)
+	for (uint32_t cChild = 0; cChild < m_children; ++cChild)
 	{
 		// if this child is already dead do not consider it.
 		if (m_ptrMBR[cChild]->m_endTime <= r.m_startTime) continue;
@@ -172,7 +176,7 @@ size_t Index::findLeastEnlargement(const TimeRegion& r) const
 	}
 
 #ifndef NDEBUG
-	if (best == std::numeric_limits<size_t>::max())
+	if (best == std::numeric_limits<uint32_t>::max())
 	{
 		std::ostringstream s;
 		s << "findLeastEnlargement: All entries of node " << m_identifier << " are dead.";
@@ -183,17 +187,17 @@ size_t Index::findLeastEnlargement(const TimeRegion& r) const
 	return best;
 }
 
-size_t Index::findLeastOverlap(const TimeRegion& r) const
+uint32_t Index::findLeastOverlap(const TimeRegion& r) const
 {
 	OverlapEntry** entries = new OverlapEntry*[m_children];
 
 	double leastOverlap = std::numeric_limits<double>::max();
 	double me = std::numeric_limits<double>::max();
 	OverlapEntry* best = 0;
-	size_t cLiveEntries = 0;
+	uint32_t cLiveEntries = 0;
 
 	// find combined region and enlargement of every entry and store it.
-	for (size_t cChild = 0; cChild < m_children; cChild++)
+	for (uint32_t cChild = 0; cChild < m_children; ++cChild)
 	{
 		if (m_ptrMBR[cChild]->m_endTime <= r.m_startTime) continue;
 
@@ -203,7 +207,7 @@ size_t Index::findLeastOverlap(const TimeRegion& r) const
 		}
 		catch (...)
 		{
-			for (size_t i = 0; i < cLiveEntries; i++) delete entries[i];
+			for (uint32_t i = 0; i < cLiveEntries; ++i) delete entries[i];
 			delete[] entries;
 			throw;
 		}
@@ -225,7 +229,7 @@ size_t Index::findLeastOverlap(const TimeRegion& r) const
 		{
 			best = entries[cLiveEntries];
 		}
-		cLiveEntries++;
+		++cLiveEntries;
 	}
 
 #ifndef NDEBUG
@@ -239,7 +243,7 @@ size_t Index::findLeastOverlap(const TimeRegion& r) const
 
 	if (me < -std::numeric_limits<double>::epsilon() || me > std::numeric_limits<double>::epsilon())
 	{
-		size_t cIterations;
+		uint32_t cIterations;
 
 		if (cLiveEntries > m_pTree->m_nearMinimumOverlapFactor)
 		{
@@ -257,12 +261,12 @@ size_t Index::findLeastOverlap(const TimeRegion& r) const
 		}
 
 		// calculate overlap of most important original entries (near minimum overlap cost).
-		for (size_t cIndex = 0; cIndex < cIterations; cIndex++)
+		for (uint32_t cIndex = 0; cIndex < cIterations; ++cIndex)
 		{
 			double dif = 0.0;
 			OverlapEntry* e = entries[cIndex];
 
-			for (size_t cChild = 0; cChild < cLiveEntries; cChild++)
+			for (uint32_t cChild = 0; cChild < cLiveEntries; ++cChild)
 			{
 				if (cIndex != cChild)
 				{
@@ -292,9 +296,9 @@ size_t Index::findLeastOverlap(const TimeRegion& r) const
 		} // for (cIndex)
 	}
 
-	size_t ret = best->m_index;
+	uint32_t ret = best->m_index;
 
-	for (size_t cChild = 0; cChild < cLiveEntries; cChild++)
+	for (uint32_t cChild = 0; cChild < cLiveEntries; ++cChild)
 	{
 		delete entries[cChild];
 	}
@@ -305,11 +309,11 @@ size_t Index::findLeastOverlap(const TimeRegion& r) const
 
 void Index::adjustTree(Node* n, std::stack<id_type>& pathBuffer)
 {
-	m_pTree->m_stats.m_adjustments++;
+	++(m_pTree->m_stats.m_u64Adjustments);
 
 	// find entry pointing to old node;
-	size_t child;
-	for (child = 0; child < m_children; child++)
+	uint32_t child;
+	for (child = 0; child < m_children; ++child)
 	{
 		if (m_pIdentifier[child] == n->m_identifier) break;
 	}
@@ -332,12 +336,12 @@ void Index::adjustTree(Node* n, std::stack<id_type>& pathBuffer)
 	{
 		// no need to update times here. The inserted MBR is younger than all nodes.
 
-		for (size_t cDim = 0; cDim < m_nodeMBR.m_dimension; cDim++)
+		for (uint32_t cDim = 0; cDim < m_nodeMBR.m_dimension; ++cDim)
 		{
 			m_nodeMBR.m_pLow[cDim] = std::numeric_limits<double>::max();
 			m_nodeMBR.m_pHigh[cDim] = -std::numeric_limits<double>::max();
 
-			for (size_t cChild = 0; cChild < m_children; cChild++)
+			for (uint32_t cChild = 0; cChild < m_children; ++cChild)
 			{
 				m_nodeMBR.m_pLow[cDim] = std::min(m_nodeMBR.m_pLow[cDim], m_ptrMBR[cChild]->m_pLow[cDim]);
 				m_nodeMBR.m_pHigh[cDim] = std::max(m_nodeMBR.m_pHigh[cDim], m_ptrMBR[cChild]->m_pHigh[cDim]);
@@ -358,11 +362,11 @@ void Index::adjustTree(Node* n, std::stack<id_type>& pathBuffer)
 
 void Index::adjustTree(Node* n, Node* nn, std::stack<id_type>& pathBuffer)
 {
-	m_pTree->m_stats.m_adjustments++;
+	++(m_pTree->m_stats.m_u64Adjustments);
 
 	// find entry pointing to old node;
-	size_t child, child2 = m_capacity;
-	for (child = 0; child < m_children; child++)
+	uint32_t child, child2 = m_capacity;
+	for (child = 0; child < m_children; ++child)
 	{
 		if (m_pIdentifier[child] == nn->m_identifier) child2 = child;
 		if (m_pIdentifier[child] == n->m_identifier) break;
@@ -370,7 +374,7 @@ void Index::adjustTree(Node* n, Node* nn, std::stack<id_type>& pathBuffer)
 
 	if (child2 == m_capacity)
 	{
-		for (child2 = child + 1; child2 < m_children; child2++)
+		for (child2 = child + 1; child2 < m_children; ++child2)
 		{
 			if (m_pIdentifier[child2] == nn->m_identifier) break;
 		}
@@ -402,12 +406,12 @@ void Index::adjustTree(Node* n, Node* nn, std::stack<id_type>& pathBuffer)
 	{
 		// no need to update times here. The inserted MBR is younger than all nodes.
 
-		for (size_t cDim = 0; cDim < m_nodeMBR.m_dimension; cDim++)
+		for (uint32_t cDim = 0; cDim < m_nodeMBR.m_dimension; ++cDim)
 		{
 			m_nodeMBR.m_pLow[cDim] = std::numeric_limits<double>::max();
 			m_nodeMBR.m_pHigh[cDim] = -std::numeric_limits<double>::max();
 
-			for (size_t cChild = 0; cChild < m_children; cChild++)
+			for (uint32_t cChild = 0; cChild < m_children; ++cChild)
 			{
 				m_nodeMBR.m_pLow[cDim] = std::min(m_nodeMBR.m_pLow[cDim], m_ptrMBR[cChild]->m_pLow[cDim]);
 				m_nodeMBR.m_pHigh[cDim] = std::max(m_nodeMBR.m_pHigh[cDim], m_ptrMBR[cChild]->m_pHigh[cDim]);
