@@ -21,35 +21,38 @@
 
 #include <cstring>
 #include <stdio.h>
+#include <cmath>
 
 #ifndef _MSC_VER
 #include <unistd.h>
 #endif
 
-#include "../spatialindex/SpatialIndexImpl.h"
+#include <spatialindex/SpatialIndex.h>
+
 #include "RTree.h"
 #include "Leaf.h"
 #include "Index.h"
 #include "BulkLoader.h"
 
+using namespace SpatialIndex;
 using namespace SpatialIndex::RTree;
 
 //
 // ExternalSorter::Record
 //
-ExternalSorter::Record::Record() : m_pData(0)
+ExternalSorter::Record::Record()
+: m_pData(0)
 {
 }
 
-ExternalSorter::Record::Record(const Region& r, id_type id, size_t len, byte* pData, size_t s)
+ExternalSorter::Record::Record(const Region& r, id_type id, uint32_t len, byte* pData, uint32_t s)
 : m_r(r), m_id(id), m_len(len), m_pData(pData), m_s(s)
 {
 }
 
 ExternalSorter::Record::~Record()
 {
-    // if (m_pData != 0)
-    //  delete[] m_pData;
+	delete[] m_pData;
 }
 
 bool ExternalSorter::Record::operator<(const Record& r) const
@@ -66,16 +69,16 @@ bool ExternalSorter::Record::operator<(const Record& r) const
 void ExternalSorter::Record::storeToFile(Tools::TemporaryFile& f)
 {
 	f.write(static_cast<uint64_t>(m_id));
-	f.write(static_cast<uint32_t>(m_r.m_dimension));
-	f.write(static_cast<uint32_t>(m_s));
+	f.write(m_r.m_dimension);
+	f.write(m_s);
 
-	for (size_t i = 0; i < m_r.m_dimension; ++i)
+	for (uint32_t i = 0; i < m_r.m_dimension; ++i)
 	{
 		f.write(m_r.m_pLow[i]);
 		f.write(m_r.m_pHigh[i]);
 	}
 
-	f.write(static_cast<uint32_t>(m_len));
+	f.write(m_len);
 	if (m_len > 0) f.write(m_len, m_pData);
 }
 
@@ -94,13 +97,13 @@ void ExternalSorter::Record::loadFromFile(Tools::TemporaryFile& f)
 		m_r.m_pHigh = new double[dim];
 	}
 
-	for (size_t i = 0; i < m_r.m_dimension; ++i)
+	for (uint32_t i = 0; i < m_r.m_dimension; ++i)
 	{
 		m_r.m_pLow[i] = f.readDouble();
 		m_r.m_pHigh[i] = f.readDouble();
 	}
-	
-	m_len = static_cast<size_t>(f.readUInt32());
+
+	m_len = f.readUInt32();
 	delete[] m_pData; m_pData = 0;
 	if (m_len > 0) f.readBytes(m_len, &m_pData);
 }
@@ -110,15 +113,13 @@ void ExternalSorter::Record::loadFromFile(Tools::TemporaryFile& f)
 //
 ExternalSorter::ExternalSorter(uint32_t u32PageSize, uint32_t u32BufferPages)
 : m_bInsertionPhase(true), m_u32PageSize(u32PageSize),
-	m_u32BufferPages(u32BufferPages), m_sortedFile(0), m_u64TotalEntries(0), m_stI(0)
+  m_u32BufferPages(u32BufferPages), m_u64TotalEntries(0), m_stI(0)
 {
 }
 
 ExternalSorter::~ExternalSorter()
 {
-	delete m_sortedFile;
 	for (m_stI = 0; m_stI < m_buffer.size(); ++m_stI) delete m_buffer[m_stI];
-
 }
 
 void ExternalSorter::insert(Record* r)
@@ -142,7 +143,7 @@ void ExternalSorter::insert(Record* r)
 		}
 		m_buffer.clear();
 		tf->rewindForReading();
-		m_runs.push_back(tf);
+		m_runs.push_back(Tools::SmartPointer<Tools::TemporaryFile>(tf));
 	}
 }
 
@@ -172,67 +173,44 @@ void ExternalSorter::sort()
 		}
 		m_buffer.clear();
 		tf->rewindForReading();
-		m_runs.push_back(tf);
+		m_runs.push_back(Tools::SmartPointer<Tools::TemporaryFile>(tf));
 	}
 
-	m_sortedFile = m_runs.front();
-
-	Record* r;
-	uint32_t u32Count;
-
-	while (m_runs.size() > 1)
+	if (m_runs.size() == 1)
 	{
-		Tools::TemporaryFile* tf = new Tools::TemporaryFile();
-		std::vector<Tools::TemporaryFile*> buckets;
-		std::vector<std::queue<Record*> > buffers;
-		std::priority_queue<PQEntry, std::vector<PQEntry>, PQEntry::SortAscending> pq;
+		m_sortedFile = m_runs.front();
+	}
+	else
+	{
+		Record* r;
 
-		// initialize buffers and priority queue.
-		std::list<Tools::TemporaryFile*>::iterator it = m_runs.begin();
-		for (uint32_t i = 0; i < (std::min)(m_runs.size(), static_cast<size_t>(m_u32BufferPages)); ++i)
+		while (m_runs.size() > 1)
 		{
-			buckets.push_back(*it);
-			buffers.push_back(std::queue<Record*>());
+			Tools::SmartPointer<Tools::TemporaryFile> tf(new Tools::TemporaryFile());
+			std::vector<Tools::SmartPointer<Tools::TemporaryFile> > buckets;
+			std::vector<std::queue<Record*> > buffers;
+			std::priority_queue<PQEntry, std::vector<PQEntry>, PQEntry::SortAscending> pq;
 
-			r = new Record();
-			r->loadFromFile(*buckets.back());
-				// a run cannot be empty initially, so this should never fail.
-			pq.push(PQEntry(r, i));
-
-			for (uint32_t j = 0; j < m_u32PageSize - 1; ++j)
+			// initialize buffers and priority queue.
+			std::list<Tools::SmartPointer<Tools::TemporaryFile> >::iterator it = m_runs.begin();
+			for (uint32_t i = 0; i < (std::min)(static_cast<uint32_t>(m_runs.size()), m_u32BufferPages); ++i)
 			{
-				// fill the buffer with the rest of the page of records.
-				try
-				{
-					r = new Record();
-					r->loadFromFile(*buckets.back());
-					buffers.back().push(r);
-				}
-				catch (Tools::EndOfStreamException)
-				{
-					delete r;
-					break;
-				}
-			}
-			++it;
-		}
+				buckets.push_back(*it);
+				buffers.push_back(std::queue<Record*>());
 
-		// exhaust buckets, buffers, and priority queue.
-		while (! pq.empty())
-		{
-			PQEntry e = pq.top(); pq.pop();
-			e.m_r->storeToFile(*tf);
-			delete e.m_r;
+				r = new Record();
+				r->loadFromFile(**it);
+					// a run cannot be empty initially, so this should never fail.
+				pq.push(PQEntry(r, i));
 
-			if (! buckets[e.m_u32Index]->eof() && buffers[e.m_u32Index].empty())
-			{
-				for (uint32_t j = 0; j < m_u32PageSize; ++j)
+				for (uint32_t j = 0; j < m_u32PageSize - 1; ++j)
 				{
+					// fill the buffer with the rest of the page of records.
 					try
 					{
 						r = new Record();
-						r->loadFromFile(*buckets[e.m_u32Index]);
-						buffers[e.m_u32Index].push(r);
+						r->loadFromFile(**it);
+						buffers.back().push(r);
 					}
 					catch (Tools::EndOfStreamException)
 					{
@@ -240,62 +218,91 @@ void ExternalSorter::sort()
 						break;
 					}
 				}
+				++it;
 			}
 
-			if (! buffers[e.m_u32Index].empty())
+			// exhaust buckets, buffers, and priority queue.
+			while (! pq.empty())
 			{
-				e.m_r = buffers[e.m_u32Index].front();
-				buffers[e.m_u32Index].pop();
-				pq.push(e);
+				PQEntry e = pq.top(); pq.pop();
+				e.m_r->storeToFile(*tf);
+				delete e.m_r;
+
+				if (! buckets[e.m_u32Index]->eof() && buffers[e.m_u32Index].empty())
+				{
+					for (uint32_t j = 0; j < m_u32PageSize; ++j)
+					{
+						try
+						{
+							r = new Record();
+							r->loadFromFile(*buckets[e.m_u32Index]);
+							buffers[e.m_u32Index].push(r);
+						}
+						catch (Tools::EndOfStreamException)
+						{
+							delete r;
+							break;
+						}
+					}
+				}
+
+				if (! buffers[e.m_u32Index].empty())
+				{
+					e.m_r = buffers[e.m_u32Index].front();
+					buffers[e.m_u32Index].pop();
+					pq.push(e);
+				}
 			}
-		}
 
-		tf->rewindForReading();
+			tf->rewindForReading();
 
-		// check if another pass is needed.
-		u32Count = m_runs.size();
-		for (uint32_t i = 0; i < (std::min)(u32Count, m_u32BufferPages); ++i)
-		{
-			delete m_runs.front();
-			m_runs.pop_front();
-		}
+			// check if another pass is needed.
+			uint32_t u32Count = std::min(static_cast<uint32_t>(m_runs.size()), m_u32BufferPages);
+			for (uint32_t i = 0; i < u32Count; ++i)
+			{
+				m_runs.pop_front();
+			}
 
-		if (m_runs.size() == 0)
-		{
-			m_sortedFile = tf;
-			break;
-		}
-		else
-		{
-			m_runs.push_back(tf);
+			if (m_runs.size() == 0)
+			{
+				m_sortedFile = tf;
+				break;
+			}
+			else
+			{
+				m_runs.push_back(tf);
+			}
 		}
 	}
 
 	m_bInsertionPhase = false;
 }
 
-void ExternalSorter::getNextRecord(Record& r)
+ExternalSorter::Record* ExternalSorter::getNextRecord()
 {
-	if (m_bInsertionPhase == true) throw Tools::IllegalStateException("ExternalSorter::getNextRecord: Input has not been sorted yet.");
+	if (m_bInsertionPhase == true)
+		throw Tools::IllegalStateException("ExternalSorter::getNextRecord: Input has not been sorted yet.");
 
-	if (m_sortedFile == 0)
+	Record* ret;
+
+	if (m_sortedFile.get() == 0)
 	{
 		if (m_stI < m_buffer.size())
-			r = *(m_buffer[m_stI++]);
+		{
+			ret = m_buffer[m_stI];
+			m_buffer[m_stI] = 0;
+			++m_stI;
+		}
 		else
 			throw Tools::EndOfStreamException("");
 	}
 	else
-		r.loadFromFile(*m_sortedFile);
-}
+	{
+		ret = new Record();
+		ret->loadFromFile(*m_sortedFile);
+	}
 
-void ExternalSorter::rewind()
-{
-	if (m_bInsertionPhase == true)
-		throw Tools::IllegalStateException("ExternalSorter::rewind: Input has not been sorted yet.");
-
-	if (m_sortedFile != 0) m_sortedFile->rewindForReading();
-	else m_stI = 0;
+	return ret;
 }
 
 inline uint64_t ExternalSorter::getTotalEntries() const
@@ -309,11 +316,16 @@ inline uint64_t ExternalSorter::getTotalEntries() const
 void BulkLoader::bulkLoadUsingSTR(
 	SpatialIndex::RTree::RTree* pTree,
 	IDataStream& stream,
-	size_t bindex,
-	size_t bleaf,
-	size_t pageSize,
-	size_t numberOfPages
+	uint32_t bindex,
+	uint32_t bleaf,
+	uint32_t pageSize,
+	uint32_t numberOfPages
 ) {
+	if (! stream.hasNext())
+		throw Tools::IllegalArgumentException(
+			"RTree::BulkLoader::bulkLoadUsingSTR: Empty data stream given."
+		);
+
 	NodePtr n = pTree->readNode(pTree->m_rootID);
 	pTree->deleteNode(n.get());
 
@@ -325,26 +337,22 @@ void BulkLoader::bulkLoadUsingSTR(
 
 	while (stream.hasNext())
 	{
-		IData* d = stream.getNext();
-
-		IShape* s; d->getShape(&s);
-		Region r; s->getMBR(r);
-		delete s;
-
-		byte* pData;
-		size_t len;
-		d->getData(len, &pData);
-
-		es->insert(new ExternalSorter::Record(r, d->getIdentifier(), len, pData, 0));
+		Data* d = reinterpret_cast<Data*>(stream.getNext());
+		if (d == 0)
+			throw Tools::IllegalArgumentException(
+				"bulkLoadUsingSTR: RTree bulk load expects SpatialIndex::RTree::Data entries."
+			);
 
+		es->insert(new ExternalSorter::Record(d->m_region, d->m_id, d->m_dataLength, d->m_pData, 0));
+		d->m_pData = 0;
 		delete d;
 	}
 	es->sort();
 
-	pTree->m_stats.m_data = es->getTotalEntries();
+	pTree->m_stats.m_u64Data = es->getTotalEntries();
 
 	// create index levels.
-	size_t level = 0;
+	uint32_t level = 0;
 
 	while (true)
 	{
@@ -354,53 +362,51 @@ void BulkLoader::bulkLoadUsingSTR(
 
 		pTree->m_stats.m_nodesInLevel.push_back(0);
 
-		Tools::SmartPointer<ExternalSorter> es2 = Tools::SmartPointer<ExternalSorter>(new ExternalSorter(800, 2000));
+		Tools::SmartPointer<ExternalSorter> es2 = Tools::SmartPointer<ExternalSorter>(new ExternalSorter(pageSize, numberOfPages));
 		createLevel(pTree, es, 0, bleaf, bindex, level++, es2, pageSize, numberOfPages);
-
 		es = es2;
 
 		if (es->getTotalEntries() == 1) break;
 		es->sort();
 	}
 
-	pTree->m_stats.m_treeHeight = level;
+	pTree->m_stats.m_u32TreeHeight = level;
 	pTree->storeHeader();
 }
 
 void BulkLoader::createLevel(
 	SpatialIndex::RTree::RTree* pTree,
 	Tools::SmartPointer<ExternalSorter> es,
-	size_t dimension,
-	size_t bleaf,
-	size_t bindex,
-	size_t level,
+	uint32_t dimension,
+	uint32_t bleaf,
+	uint32_t bindex,
+	uint32_t level,
 	Tools::SmartPointer<ExternalSorter> es2,
-	size_t pageSize,
-	size_t numberOfPages
+	uint32_t pageSize,
+	uint32_t numberOfPages
 ) {
-	size_t b = (level == 0) ? bleaf : bindex;
-	size_t P = static_cast<size_t>(std::ceil(static_cast<double>(es->getTotalEntries()) / static_cast<double>(b)));
-	size_t S = static_cast<size_t>(std::ceil(std::sqrt(static_cast<double>(P))));
+	uint64_t b = (level == 0) ? bleaf : bindex;
+	uint64_t P = static_cast<uint64_t>(std::ceil(static_cast<double>(es->getTotalEntries()) / static_cast<double>(b)));
+	uint64_t S = static_cast<uint64_t>(std::ceil(std::sqrt(static_cast<double>(P))));
 
-	if (S == 1 || dimension == pTree->m_dimension - 1)
+	if (S == 1 || dimension == pTree->m_dimension - 1 || S * b == es->getTotalEntries())
 	{
-		// store new pages in storage manager and page information in temporary file.
-		std::vector<ExternalSorter::Record> node;
-		ExternalSorter::Record r;
-		
+		std::vector<ExternalSorter::Record*> node;
+		ExternalSorter::Record* r;
+
 		while (true)
 		{
-			try { es->getNextRecord(r); } catch (Tools::EndOfStreamException) { break; }
+			try { r = es->getNextRecord(); } catch (Tools::EndOfStreamException) { break; }
 			node.push_back(r);
 
 			if (node.size() == b)
 			{
 				Node* n = createNode(pTree, node, level);
+				node.clear();
 				pTree->writeNode(n);
 				es2->insert(new ExternalSorter::Record(n->m_nodeMBR, n->m_identifier, 0, 0, 0));
 				pTree->m_rootID = n->m_identifier;
 					// special case when the root has exactly bindex entries.
-				node.clear();
 				delete n;
 			}
 		}
@@ -420,21 +426,23 @@ void BulkLoader::createLevel(
 
 		while (bMore)
 		{
+			ExternalSorter::Record* pR;
 			Tools::SmartPointer<ExternalSorter> es3 = Tools::SmartPointer<ExternalSorter>(new ExternalSorter(pageSize, numberOfPages));
-			for (size_t i = 0; i < S * b; ++i)
+			
+			for (uint64_t i = 0; i < S * b; ++i)
 			{
-				ExternalSorter::Record* pR = new ExternalSorter::Record();
-				try { es->getNextRecord(*pR); } catch (Tools::EndOfStreamException) { bMore = false; break; }
+				try { pR = es->getNextRecord(); }
+				catch (Tools::EndOfStreamException) { bMore = false; break; }
 				pR->m_s = dimension + 1;
 				es3->insert(pR);
 			}
 			es3->sort();
-			createLevel(pTree, es3, dimension + 1, bindex, bleaf, level, es2, pageSize, numberOfPages);
+			createLevel(pTree, es3, dimension + 1, bleaf, bindex, level, es2, pageSize, numberOfPages);
 		}
 	}
 }
 
-Node* BulkLoader::createNode(SpatialIndex::RTree::RTree* pTree, std::vector<ExternalSorter::Record>& e, size_t level)
+Node* BulkLoader::createNode(SpatialIndex::RTree::RTree* pTree, std::vector<ExternalSorter::Record*>& e, uint32_t level)
 {
 	Node* n;
 
@@ -443,10 +451,10 @@ Node* BulkLoader::createNode(SpatialIndex::RTree::RTree* pTree, std::vector<Exte
 
 	for (size_t cChild = 0; cChild < e.size(); ++cChild)
 	{
-		n->insertEntry(e[cChild].m_len, e[cChild].m_pData, e[cChild].m_r, e[cChild].m_id);
-		e[cChild].m_pData = 0;
+		n->insertEntry(e[cChild]->m_len, e[cChild]->m_pData, e[cChild]->m_r, e[cChild]->m_id);
+		e[cChild]->m_pData = 0;
+		delete e[cChild];
 	}
 
 	return n;
 }
-
