@@ -20,8 +20,10 @@
 //    mhadji@gmail.com
 
 #include <cstring>
+#include <cmath>
+#include <limits>
 
-#include "../spatialindex/SpatialIndexImpl.h"
+#include <spatialindex/SpatialIndex.h>
 #include "Node.h"
 #include "Leaf.h"
 #include "Index.h"
@@ -29,8 +31,9 @@
 #include "RTree.h"
 
 using namespace SpatialIndex::RTree;
+using namespace SpatialIndex;
 
-SpatialIndex::RTree::Data::Data(size_t len, byte* pData, Region& r, id_type id)
+SpatialIndex::RTree::Data::Data(uint32_t len, byte* pData, Region& r, id_type id)
 	: m_id(id), m_region(r), m_pData(0), m_dataLength(len)
 {
 	if (m_dataLength > 0)
@@ -60,7 +63,7 @@ void SpatialIndex::RTree::Data::getShape(IShape** out) const
 	*out = new Region(m_region);
 }
 
-void SpatialIndex::RTree::Data::getData(size_t& len, byte** data) const
+void SpatialIndex::RTree::Data::getData(uint32_t& len, byte** data) const
 {
 	len = m_dataLength;
 	*data = 0;
@@ -72,11 +75,11 @@ void SpatialIndex::RTree::Data::getData(size_t& len, byte** data) const
 	}
 }
 
-size_t SpatialIndex::RTree::Data::getByteArraySize()
+uint32_t SpatialIndex::RTree::Data::getByteArraySize()
 {
 	return
 		sizeof(id_type) +
-		sizeof(size_t) +
+		sizeof(uint32_t) +
 		m_dataLength +
 		m_region.getByteArraySize();
 }
@@ -89,8 +92,8 @@ void SpatialIndex::RTree::Data::loadFromByteArray(const byte* ptr)
 	delete[] m_pData;
 	m_pData = 0;
 
-	memcpy(&m_dataLength, ptr, sizeof(size_t));
-	ptr += sizeof(size_t);
+	memcpy(&m_dataLength, ptr, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
 
 	if (m_dataLength > 0)
 	{
@@ -102,22 +105,22 @@ void SpatialIndex::RTree::Data::loadFromByteArray(const byte* ptr)
 	m_region.loadFromByteArray(ptr);
 }
 
-void SpatialIndex::RTree::Data::storeToByteArray(byte** data, size_t& len)
+void SpatialIndex::RTree::Data::storeToByteArray(byte** data, uint32_t& len)
 {
 	// it is thread safe this way.
-	size_t regionsize;
+	uint32_t regionsize;
 	byte* regiondata = 0;
 	m_region.storeToByteArray(&regiondata, regionsize);
 
-	len = sizeof(id_type) + sizeof(size_t) + m_dataLength + regionsize;
+	len = sizeof(id_type) + sizeof(uint32_t) + m_dataLength + regionsize;
 
 	*data = new byte[len];
 	byte* ptr = *data;
 
 	memcpy(ptr, &m_id, sizeof(id_type));
 	ptr += sizeof(id_type);
-	memcpy(ptr, &m_dataLength, sizeof(size_t));
-	ptr += sizeof(size_t);
+	memcpy(ptr, &m_dataLength, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
 
 	if (m_dataLength > 0)
 	{
@@ -139,9 +142,9 @@ SpatialIndex::ISpatialIndex* SpatialIndex::RTree::returnRTree(SpatialIndex::ISto
 SpatialIndex::ISpatialIndex* SpatialIndex::RTree::createNewRTree(
 	SpatialIndex::IStorageManager& sm,
 	double fillFactor,
-	size_t indexCapacity,
-	size_t leafCapacity,
-	size_t dimension,
+	uint32_t indexCapacity,
+	uint32_t leafCapacity,
+	uint32_t dimension,
 	RTreeVariant rv,
 	id_type& indexIdentifier)
 {
@@ -182,23 +185,148 @@ SpatialIndex::ISpatialIndex* SpatialIndex::RTree::createAndBulkLoadNewRTree(
 	IDataStream& stream,
 	SpatialIndex::IStorageManager& sm,
 	double fillFactor,
-	size_t indexCapacity,
-	size_t leafCapacity,
-	size_t dimension,
+	uint32_t indexCapacity,
+	uint32_t leafCapacity,
+	uint32_t dimension,
 	SpatialIndex::RTree::RTreeVariant rv,
 	id_type& indexIdentifier)
 {
 	SpatialIndex::ISpatialIndex* tree = createNewRTree(sm, fillFactor, indexCapacity, leafCapacity, dimension, rv, indexIdentifier);
 
-	size_t bindex = static_cast<size_t>(std::floor(static_cast<double>(indexCapacity * fillFactor)));
-	size_t bleaf = static_cast<size_t>(std::floor(static_cast<double>(leafCapacity * fillFactor)));
+	uint32_t bindex = static_cast<uint32_t>(std::floor(static_cast<double>(indexCapacity * fillFactor)));
+	uint32_t bleaf = static_cast<uint32_t>(std::floor(static_cast<double>(leafCapacity * fillFactor)));
 
 	SpatialIndex::RTree::BulkLoader bl;
 
 	switch (m)
 	{
 	case BLM_STR:
-		bl.bulkLoadUsingSTR(static_cast<RTree*>(tree), stream, bindex, bleaf, 500, 2000);
+		bl.bulkLoadUsingSTR(static_cast<RTree*>(tree), stream, bindex, bleaf, 10000, 100);
+		break;
+	default:
+		throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Unknown bulk load method.");
+		break;
+	}
+
+	return tree;
+}
+
+SpatialIndex::ISpatialIndex* SpatialIndex::RTree::createAndBulkLoadNewRTree(
+	BulkLoadMethod m,
+	IDataStream& stream,
+	SpatialIndex::IStorageManager& sm,
+	Tools::PropertySet& ps,
+	id_type& indexIdentifier)
+{
+	Tools::Variant var;
+	RTreeVariant rv(RV_LINEAR);
+	double fillFactor(0.0);
+	uint32_t indexCapacity(0);
+	uint32_t leafCapacity(0);
+	uint32_t dimension(0);
+	uint32_t pageSize(0);
+	uint32_t numberOfPages(0);
+
+	// tree variant
+	var = ps.getProperty("TreeVariant");
+	if (var.m_varType != Tools::VT_EMPTY)
+	{
+		if (
+			var.m_varType != Tools::VT_LONG ||
+			(var.m_val.lVal != RV_LINEAR &&
+			var.m_val.lVal != RV_QUADRATIC &&
+			var.m_val.lVal != RV_RSTAR))
+			throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Property TreeVariant must be Tools::VT_LONG and of RTreeVariant type");
+
+		rv = static_cast<RTreeVariant>(var.m_val.lVal);
+	}
+
+	// fill factor
+	// it cannot be larger than 50%, since linear and quadratic split algorithms
+	// require assigning to both nodes the same number of entries.
+	var = ps.getProperty("FillFactor");
+	if (var.m_varType != Tools::VT_EMPTY)
+	{
+	    if (var.m_varType != Tools::VT_DOUBLE)
+            throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Property FillFactor was not of type Tools::VT_DOUBLE");
+        
+        if (var.m_val.dblVal <= 0.0)
+            throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Property FillFactor was less than 0.0");
+        
+        if (((rv == RV_LINEAR || rv == RV_QUADRATIC) && var.m_val.dblVal > 0.5))
+            throw Tools::IllegalArgumentException( "createAndBulkLoadNewRTree: Property FillFactor must be in range (0.0, 0.5) for LINEAR or QUADRATIC index types");
+        if ( var.m_val.dblVal >= 1.0)
+            throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Property FillFactor must be in range (0.0, 1.0) for RSTAR index type");
+		fillFactor = var.m_val.dblVal;
+	}
+
+	// index capacity
+	var = ps.getProperty("IndexCapacity");
+	if (var.m_varType != Tools::VT_EMPTY)
+	{
+		if (var.m_varType != Tools::VT_ULONG || var.m_val.ulVal < 4)
+			throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Property IndexCapacity must be Tools::VT_ULONG and >= 4");
+
+		indexCapacity = var.m_val.ulVal;
+	}
+
+	// leaf capacity
+	var = ps.getProperty("LeafCapacity");
+	if (var.m_varType != Tools::VT_EMPTY)
+	{
+		if (var.m_varType != Tools::VT_ULONG || var.m_val.ulVal < 4)
+			throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Property LeafCapacity must be Tools::VT_ULONG and >= 4");
+
+		leafCapacity = var.m_val.ulVal;
+	}
+
+	// dimension
+	var = ps.getProperty("Dimension");
+	if (var.m_varType != Tools::VT_EMPTY)
+	{
+		if (var.m_varType != Tools::VT_ULONG)
+			throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Property Dimension must be Tools::VT_ULONG");
+		if (var.m_val.ulVal <= 1)
+			throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Property Dimension must be greater than 1");
+
+		dimension = var.m_val.ulVal;
+	}
+
+	// page size
+	var = ps.getProperty("ExternalSortBufferPageSize");
+	if (var.m_varType != Tools::VT_EMPTY)
+	{
+		if (var.m_varType != Tools::VT_ULONG)
+			throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Property ExternalSortBufferPageSize must be Tools::VT_ULONG");
+		if (var.m_val.ulVal <= 1)
+			throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Property ExternalSortBufferPageSize must be greater than 1");
+
+		pageSize = var.m_val.ulVal;
+	}
+
+	// number of pages
+	var = ps.getProperty("ExternalSortBufferTotalPages");
+	if (var.m_varType != Tools::VT_EMPTY)
+	{
+		if (var.m_varType != Tools::VT_ULONG)
+			throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Property ExternalSortBufferTotalPages must be Tools::VT_ULONG");
+		if (var.m_val.ulVal <= 1)
+			throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Property ExternalSortBufferTotalPages must be greater than 1");
+
+		numberOfPages = var.m_val.ulVal;
+	}
+
+	SpatialIndex::ISpatialIndex* tree = createNewRTree(sm, fillFactor, indexCapacity, leafCapacity, dimension, rv, indexIdentifier);
+
+	uint32_t bindex = static_cast<uint32_t>(std::floor(static_cast<double>(indexCapacity * fillFactor)));
+	uint32_t bleaf = static_cast<uint32_t>(std::floor(static_cast<double>(leafCapacity * fillFactor)));
+
+	SpatialIndex::RTree::BulkLoader bl;
+
+	switch (m)
+	{
+	case BLM_STR:
+		bl.bulkLoadUsingSTR(static_cast<RTree*>(tree), stream, bindex, bleaf, pageSize, numberOfPages);
 		break;
 	default:
 		throw Tools::IllegalArgumentException("createAndBulkLoadNewRTree: Unknown bulk load method.");
@@ -238,7 +366,7 @@ SpatialIndex::RTree::RTree::RTree(IStorageManager& sm, Tools::PropertySet& ps) :
 	m_indexPool(100),
 	m_leafPool(100)
 {
-#ifdef PTHREADS
+#ifdef HAVE_PTHREAD_H
 	pthread_rwlock_init(&m_rwLock, NULL);
 #else
 	m_rwLock = false;
@@ -265,7 +393,7 @@ SpatialIndex::RTree::RTree::RTree(IStorageManager& sm, Tools::PropertySet& ps) :
 
 SpatialIndex::RTree::RTree::~RTree()
 {
-#ifdef PTHREADS
+#ifdef HAVE_PTHREAD_H
 	pthread_rwlock_destroy(&m_rwLock);
 #endif
 
@@ -276,11 +404,11 @@ SpatialIndex::RTree::RTree::~RTree()
 // ISpatialIndex interface
 //
 
-void SpatialIndex::RTree::RTree::insertData(size_t len, const byte* pData, const IShape& shape, id_type id)
+void SpatialIndex::RTree::RTree::insertData(uint32_t len, const byte* pData, const IShape& shape, id_type id)
 {
 	if (shape.getDimension() != m_dimension) throw Tools::IllegalArgumentException("insertData: Shape has the wrong number of dimensions.");
 
-#ifdef PTHREADS
+#ifdef HAVE_PTHREAD_H
 	Tools::ExclusiveLock lock(&m_rwLock);
 #else
 	if (m_rwLock == false) m_rwLock = true;
@@ -304,13 +432,13 @@ void SpatialIndex::RTree::RTree::insertData(size_t len, const byte* pData, const
 		insertData_impl(len, buffer, *mbr, id);
 			// the buffer is stored in the tree. Do not delete here.
 
-#ifndef PTHREADS
+#ifndef HAVE_PTHREAD_H
 		m_rwLock = false;
 #endif
 	}
 	catch (...)
 	{
-#ifndef PTHREADS
+#ifndef HAVE_PTHREAD_H
 		m_rwLock = false;
 #endif
 		throw;
@@ -321,7 +449,7 @@ bool SpatialIndex::RTree::RTree::deleteData(const IShape& shape, id_type id)
 {
 	if (shape.getDimension() != m_dimension) throw Tools::IllegalArgumentException("deleteData: Shape has the wrong number of dimensions.");
 
-#ifdef PTHREADS
+#ifdef HAVE_PTHREAD_H
 	Tools::ExclusiveLock lock(&m_rwLock);
 #else
 	if (m_rwLock == false) m_rwLock = true;
@@ -334,7 +462,7 @@ bool SpatialIndex::RTree::RTree::deleteData(const IShape& shape, id_type id)
 		shape.getMBR(*mbr);
 		bool ret = deleteData_impl(*mbr, id);
 
-#ifndef PTHREADS
+#ifndef HAVE_PTHREAD_H
 		m_rwLock = false;
 #endif
 
@@ -342,7 +470,7 @@ bool SpatialIndex::RTree::RTree::deleteData(const IShape& shape, id_type id)
 	}
 	catch (...)
 	{
-#ifndef PTHREADS
+#ifndef HAVE_PTHREAD_H
 		m_rwLock = false;
 #endif
 		throw;
@@ -372,7 +500,7 @@ void SpatialIndex::RTree::RTree::nearestNeighborQuery(uint32_t k, const IShape&
 {
 	if (query.getDimension() != m_dimension) throw Tools::IllegalArgumentException("nearestNeighborQuery: Shape has the wrong number of dimensions.");
 
-#ifdef PTHREADS
+#ifdef HAVE_PTHREAD_H
 	Tools::SharedLock lock(&m_rwLock);
 #else
 	if (m_rwLock == false) m_rwLock = true;
@@ -385,7 +513,7 @@ void SpatialIndex::RTree::RTree::nearestNeighborQuery(uint32_t k, const IShape&
 
 		queue.push(new NNEntry(m_rootID, 0, 0.0));
 
-		size_t count = 0;
+		uint32_t count = 0;
 		double knearest = 0.0;
 
 		while (! queue.empty())
@@ -404,7 +532,7 @@ void SpatialIndex::RTree::RTree::nearestNeighborQuery(uint32_t k, const IShape&
 				NodePtr n = readNode(pFirst->m_id);
 				v.visitNode(*n);
 
-				for (size_t cChild = 0; cChild < n->m_children; cChild++)
+				for (uint32_t cChild = 0; cChild < n->m_children; ++cChild)
 				{
 					if (n->m_level == 0)
 					{
@@ -422,8 +550,8 @@ void SpatialIndex::RTree::RTree::nearestNeighborQuery(uint32_t k, const IShape&
 			else
 			{
 				v.visitData(*(static_cast<IData*>(pFirst->m_pEntry)));
-				m_stats.m_queryResults++;
-				count++;
+				++(m_stats.m_u64QueryResults);
+				++count;
 				knearest = pFirst->m_minDist;
 				delete pFirst->m_pEntry;
 			}
@@ -438,13 +566,13 @@ void SpatialIndex::RTree::RTree::nearestNeighborQuery(uint32_t k, const IShape&
 			delete e;
 		}
 
-#ifndef PTHREADS
+#ifndef HAVE_PTHREAD_H
 		m_rwLock = false;
 #endif
 	}
 	catch (...)
 	{
-#ifndef PTHREADS
+#ifndef HAVE_PTHREAD_H
 		m_rwLock = false;
 #endif
 		throw;
@@ -464,7 +592,7 @@ void SpatialIndex::RTree::RTree::selfJoinQuery(const IShape& query, IVisitor& v)
 	if (query.getDimension() != m_dimension)
 		throw Tools::IllegalArgumentException("selfJoinQuery: Shape has the wrong number of dimensions.");
 
-#ifdef PTHREADS
+#ifdef HAVE_PTHREAD_H
 	Tools::SharedLock lock(&m_rwLock);
 #else
 	if (m_rwLock == false) m_rwLock = true;
@@ -477,13 +605,13 @@ void SpatialIndex::RTree::RTree::selfJoinQuery(const IShape& query, IVisitor& v)
 		query.getMBR(*mbr);
 		selfJoinQuery(m_rootID, m_rootID, *mbr, v);
 
-#ifndef PTHREADS
+#ifndef HAVE_PTHREAD_H
 		m_rwLock = false;
 #endif
 	}
 	catch (...)
 	{
-#ifndef PTHREADS
+#ifndef HAVE_PTHREAD_H
 		m_rwLock = false;
 #endif
 		throw;
@@ -492,7 +620,7 @@ void SpatialIndex::RTree::RTree::selfJoinQuery(const IShape& query, IVisitor& v)
 
 void SpatialIndex::RTree::RTree::queryStrategy(IQueryStrategy& qs)
 {
-#ifdef PTHREADS
+#ifdef HAVE_PTHREAD_H
 	Tools::SharedLock lock(&m_rwLock);
 #else
 	if (m_rwLock == false) m_rwLock = true;
@@ -510,13 +638,13 @@ void SpatialIndex::RTree::RTree::queryStrategy(IQueryStrategy& qs)
 			qs.getNextEntry(*n, next, hasNext);
 		}
 
-#ifndef PTHREADS
+#ifndef HAVE_PTHREAD_H
 		m_rwLock = false;
 #endif
 	}
 	catch (...)
 	{
-#ifndef PTHREADS
+#ifndef HAVE_PTHREAD_H
 		m_rwLock = false;
 #endif
 		throw;
@@ -615,14 +743,14 @@ bool SpatialIndex::RTree::RTree::isIndexValid()
 	std::stack<ValidateEntry> st;
 	NodePtr root = readNode(m_rootID);
 
-	if (root->m_level != m_stats.m_treeHeight - 1)
+	if (root->m_level != m_stats.m_u32TreeHeight - 1)
 	{
 		std::cerr << "Invalid tree height." << std::endl;
 		return false;
 	}
 
-	std::map<size_t, size_t> nodesInLevel;
-	nodesInLevel.insert(std::pair<size_t, size_t>(root->m_level, 1));
+	std::map<uint32_t, uint32_t> nodesInLevel;
+	nodesInLevel.insert(std::pair<uint32_t, uint32_t>(root->m_level, 1));
 
 	ValidateEntry e(root->m_nodeMBR, root);
 	st.push(e);
@@ -634,12 +762,12 @@ bool SpatialIndex::RTree::RTree::isIndexValid()
 		Region tmpRegion;
 		tmpRegion = m_infiniteRegion;
 
-		for (size_t cDim = 0; cDim < tmpRegion.m_dimension; cDim++)
+		for (uint32_t cDim = 0; cDim < tmpRegion.m_dimension; ++cDim)
 		{
 			tmpRegion.m_pLow[cDim] = std::numeric_limits<double>::max();
 			tmpRegion.m_pHigh[cDim] = -std::numeric_limits<double>::max();
 
-			for (size_t cChild = 0; cChild < e.m_pNode->m_children; cChild++)
+			for (uint32_t cChild = 0; cChild < e.m_pNode->m_children; ++cChild)
 			{
 				tmpRegion.m_pLow[cDim] = std::min(tmpRegion.m_pLow[cDim], e.m_pNode->m_ptrMBR[cChild]->m_pLow[cDim]);
 				tmpRegion.m_pHigh[cDim] = std::max(tmpRegion.m_pHigh[cDim], e.m_pNode->m_ptrMBR[cChild]->m_pHigh[cDim]);
@@ -659,16 +787,16 @@ bool SpatialIndex::RTree::RTree::isIndexValid()
 
 		if (e.m_pNode->m_level != 0)
 		{
-			for (size_t cChild = 0; cChild < e.m_pNode->m_children; cChild++)
+			for (uint32_t cChild = 0; cChild < e.m_pNode->m_children; ++cChild)
 			{
 				NodePtr ptrN = readNode(e.m_pNode->m_pIdentifier[cChild]);
 				ValidateEntry tmpEntry(*(e.m_pNode->m_ptrMBR[cChild]), ptrN);
 
-				std::map<size_t, size_t>::iterator itNodes = nodesInLevel.find(tmpEntry.m_pNode->m_level);
+				std::map<uint32_t, uint32_t>::iterator itNodes = nodesInLevel.find(tmpEntry.m_pNode->m_level);
 
 				if (itNodes == nodesInLevel.end())
 				{
-					nodesInLevel.insert(std::pair<size_t, size_t>(tmpEntry.m_pNode->m_level, 1l));
+					nodesInLevel.insert(std::pair<uint32_t, uint32_t>(tmpEntry.m_pNode->m_level, 1l));
 				}
 				else
 				{
@@ -680,8 +808,8 @@ bool SpatialIndex::RTree::RTree::isIndexValid()
 		}
 	}
 
-	size_t nodes = 0;
-	for (size_t cLevel = 0; cLevel < m_stats.m_treeHeight; cLevel++)
+	uint32_t nodes = 0;
+	for (uint32_t cLevel = 0; cLevel < m_stats.m_u32TreeHeight; ++cLevel)
 	{
 		if (nodesInLevel[cLevel] != m_stats.m_nodesInLevel[cLevel])
 		{
@@ -692,7 +820,7 @@ bool SpatialIndex::RTree::RTree::isIndexValid()
 		nodes += m_stats.m_nodesInLevel[cLevel];
 	}
 
-	if (nodes != m_stats.m_nodes)
+	if (nodes != m_stats.m_u32Nodes)
 	{
 		std::cerr << "Invalid number of nodes information." << std::endl;
 		ret = false;
@@ -869,7 +997,7 @@ void SpatialIndex::RTree::RTree::initNew(Tools::PropertySet& ps)
 
 	m_infiniteRegion.makeInfinite(m_dimension);
 
-	m_stats.m_treeHeight = 1;
+	m_stats.m_u32TreeHeight = 1;
 	m_stats.m_nodesInLevel.push_back(0);
 
 	Leaf root(this, -1);
@@ -985,21 +1113,21 @@ void SpatialIndex::RTree::RTree::initOld(Tools::PropertySet& ps)
 
 void SpatialIndex::RTree::RTree::storeHeader()
 {
-	const size_t headerSize =
+	const uint32_t headerSize =
 		sizeof(id_type) +						// m_rootID
 		sizeof(RTreeVariant) +					// m_treeVariant
 		sizeof(double) +						// m_fillFactor
-		sizeof(size_t) +						// m_indexCapacity
-		sizeof(size_t) +						// m_leafCapacity
-		sizeof(size_t) +						// m_nearMinimumOverlapFactor
+		sizeof(uint32_t) +						// m_indexCapacity
+		sizeof(uint32_t) +						// m_leafCapacity
+		sizeof(uint32_t) +						// m_nearMinimumOverlapFactor
 		sizeof(double) +						// m_splitDistributionFactor
 		sizeof(double) +						// m_reinsertFactor
-		sizeof(size_t) +						// m_dimension
+		sizeof(uint32_t) +						// m_dimension
 		sizeof(char) +							// m_bTightMBRs
-		sizeof(size_t) +						// m_stats.m_nodes
-		sizeof(size_t) +						// m_stats.m_data
-		sizeof(size_t) +						// m_stats.m_treeHeight
-		m_stats.m_treeHeight * sizeof(size_t);	// m_stats.m_nodesInLevel
+		sizeof(uint32_t) +						// m_stats.m_nodes
+		sizeof(uint64_t) +						// m_stats.m_data
+		sizeof(uint32_t) +						// m_stats.m_treeHeight
+		m_stats.m_u32TreeHeight * sizeof(uint32_t);	// m_stats.m_nodesInLevel
 
 	byte* header = new byte[headerSize];
 	byte* ptr = header;
@@ -1010,32 +1138,32 @@ void SpatialIndex::RTree::RTree::storeHeader()
 	ptr += sizeof(RTreeVariant);
 	memcpy(ptr, &m_fillFactor, sizeof(double));
 	ptr += sizeof(double);
-	memcpy(ptr, &m_indexCapacity, sizeof(size_t));
-	ptr += sizeof(size_t);
-	memcpy(ptr, &m_leafCapacity, sizeof(size_t));
-	ptr += sizeof(size_t);
-	memcpy(ptr, &m_nearMinimumOverlapFactor, sizeof(size_t));
-	ptr += sizeof(size_t);
+	memcpy(ptr, &m_indexCapacity, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
+	memcpy(ptr, &m_leafCapacity, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
+	memcpy(ptr, &m_nearMinimumOverlapFactor, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
 	memcpy(ptr, &m_splitDistributionFactor, sizeof(double));
 	ptr += sizeof(double);
 	memcpy(ptr, &m_reinsertFactor, sizeof(double));
 	ptr += sizeof(double);
-	memcpy(ptr, &m_dimension, sizeof(size_t));
-	ptr += sizeof(size_t);
+	memcpy(ptr, &m_dimension, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
 	char c = (char) m_bTightMBRs;
 	memcpy(ptr, &c, sizeof(char));
 	ptr += sizeof(char);
-	memcpy(ptr, &(m_stats.m_nodes), sizeof(size_t));
-	ptr += sizeof(size_t);
-	memcpy(ptr, &(m_stats.m_data), sizeof(size_t));
-	ptr += sizeof(size_t);
-	memcpy(ptr, &(m_stats.m_treeHeight), sizeof(size_t));
-	ptr += sizeof(size_t);
+	memcpy(ptr, &(m_stats.m_u32Nodes), sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
+	memcpy(ptr, &(m_stats.m_u64Data), sizeof(uint64_t));
+	ptr += sizeof(uint64_t);
+	memcpy(ptr, &(m_stats.m_u32TreeHeight), sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
 
-	for (size_t cLevel = 0; cLevel < m_stats.m_treeHeight; ++cLevel)
+	for (uint32_t cLevel = 0; cLevel < m_stats.m_u32TreeHeight; ++cLevel)
 	{
-		memcpy(ptr, &(m_stats.m_nodesInLevel[cLevel]), sizeof(size_t));
-		ptr += sizeof(size_t);
+		memcpy(ptr, &(m_stats.m_nodesInLevel[cLevel]), sizeof(uint32_t));
+		ptr += sizeof(uint32_t);
 	}
 
 	m_pStorageManager->storeByteArray(m_headerID, headerSize, header);
@@ -1045,7 +1173,7 @@ void SpatialIndex::RTree::RTree::storeHeader()
 
 void SpatialIndex::RTree::RTree::loadHeader()
 {
-	size_t headerSize;
+	uint32_t headerSize;
 	byte* header = 0;
 	m_pStorageManager->loadByteArray(m_headerID, headerSize, &header);
 
@@ -1057,41 +1185,41 @@ void SpatialIndex::RTree::RTree::loadHeader()
 	ptr += sizeof(RTreeVariant);
 	memcpy(&m_fillFactor, ptr, sizeof(double));
 	ptr += sizeof(double);
-	memcpy(&m_indexCapacity, ptr, sizeof(size_t));
-	ptr += sizeof(size_t);
-	memcpy(&m_leafCapacity, ptr, sizeof(size_t));
-	ptr += sizeof(size_t);
-	memcpy(&m_nearMinimumOverlapFactor, ptr, sizeof(size_t));
-	ptr += sizeof(size_t);
+	memcpy(&m_indexCapacity, ptr, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
+	memcpy(&m_leafCapacity, ptr, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
+	memcpy(&m_nearMinimumOverlapFactor, ptr, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
 	memcpy(&m_splitDistributionFactor, ptr, sizeof(double));
 	ptr += sizeof(double);
 	memcpy(&m_reinsertFactor, ptr, sizeof(double));
 	ptr += sizeof(double);
-	memcpy(&m_dimension, ptr, sizeof(size_t));
-	ptr += sizeof(size_t);
+	memcpy(&m_dimension, ptr, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
 	char c;
 	memcpy(&c, ptr, sizeof(char));
 	m_bTightMBRs = (c != 0);
 	ptr += sizeof(char);
-	memcpy(&(m_stats.m_nodes), ptr, sizeof(size_t));
-	ptr += sizeof(size_t);
-	memcpy(&(m_stats.m_data), ptr, sizeof(size_t));
-	ptr += sizeof(size_t);
-	memcpy(&(m_stats.m_treeHeight), ptr, sizeof(size_t));
-	ptr += sizeof(size_t);
+	memcpy(&(m_stats.m_u32Nodes), ptr, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
+	memcpy(&(m_stats.m_u64Data), ptr, sizeof(uint64_t));
+	ptr += sizeof(uint64_t);
+	memcpy(&(m_stats.m_u32TreeHeight), ptr, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
 
-	for (size_t cLevel = 0; cLevel < m_stats.m_treeHeight; cLevel++)
+	for (uint32_t cLevel = 0; cLevel < m_stats.m_u32TreeHeight; ++cLevel)
 	{
-		size_t cNodes;
-		memcpy(&cNodes, ptr, sizeof(size_t));
-		ptr += sizeof(size_t);
+		uint32_t cNodes;
+		memcpy(&cNodes, ptr, sizeof(uint32_t));
+		ptr += sizeof(uint32_t);
 		m_stats.m_nodesInLevel.push_back(cNodes);
 	}
 
 	delete[] header;
 }
 
-void SpatialIndex::RTree::RTree::insertData_impl(size_t dataLength, byte* pData, Region& mbr, id_type id)
+void SpatialIndex::RTree::RTree::insertData_impl(uint32_t dataLength, byte* pData, Region& mbr, id_type id)
 {
 	assert(mbr.getDimension() == m_dimension);
 
@@ -1114,7 +1242,7 @@ void SpatialIndex::RTree::RTree::insertData_impl(size_t dataLength, byte* pData,
 		l->insertData(dataLength, pData, mbr, id, pathBuffer, overflowTable);
 
 		delete[] overflowTable;
-		++(m_stats.m_data);
+		++(m_stats.m_u64Data);
 	}
 	catch (...)
 	{
@@ -1123,7 +1251,7 @@ void SpatialIndex::RTree::RTree::insertData_impl(size_t dataLength, byte* pData,
 	}
 }
 
-void SpatialIndex::RTree::RTree::insertData_impl(size_t dataLength, byte* pData, Region& mbr, id_type id, size_t level, byte* overflowTable)
+void SpatialIndex::RTree::RTree::insertData_impl(uint32_t dataLength, byte* pData, Region& mbr, id_type id, uint32_t level, byte* overflowTable)
 {
 	assert(mbr.getDimension() == m_dimension);
 
@@ -1158,7 +1286,7 @@ bool SpatialIndex::RTree::RTree::deleteData_impl(const Region& mbr, id_type id)
 	{
 		Leaf* pL = static_cast<Leaf*>(l.get());
 		pL->deleteData(id, pathBuffer);
-		--(m_stats.m_data);
+		--(m_stats.m_u64Data);
 		return true;
 	}
 
@@ -1168,7 +1296,7 @@ bool SpatialIndex::RTree::RTree::deleteData_impl(const Region& mbr, id_type id)
 SpatialIndex::id_type SpatialIndex::RTree::RTree::writeNode(Node* n)
 {
 	byte* buffer;
-	size_t dataLength;
+	uint32_t dataLength;
 	n->storeToByteArray(&buffer, dataLength);
 
 	id_type page;
@@ -1190,7 +1318,7 @@ SpatialIndex::id_type SpatialIndex::RTree::RTree::writeNode(Node* n)
 	if (n->m_identifier < 0)
 	{
 		n->m_identifier = page;
-		++(m_stats.m_nodes);
+		++(m_stats.m_u32Nodes);
 
 #ifndef NDEBUG
 		try
@@ -1206,7 +1334,7 @@ SpatialIndex::id_type SpatialIndex::RTree::RTree::writeNode(Node* n)
 #endif
 	}
 
-	++(m_stats.m_writes);
+	++(m_stats.m_u64Writes);
 
 	for (size_t cIndex = 0; cIndex < m_writeNodeCommands.size(); ++cIndex)
 	{
@@ -1218,7 +1346,7 @@ SpatialIndex::id_type SpatialIndex::RTree::RTree::writeNode(Node* n)
 
 SpatialIndex::RTree::NodePtr SpatialIndex::RTree::RTree::readNode(id_type page)
 {
-	size_t dataLength;
+	uint32_t dataLength;
 	byte* buffer;
 
 	try
@@ -1233,8 +1361,8 @@ SpatialIndex::RTree::NodePtr SpatialIndex::RTree::RTree::readNode(id_type page)
 
 	try
 	{
-		size_t nodeType;
-		memcpy(&nodeType, buffer, sizeof(size_t));
+		uint32_t nodeType;
+		memcpy(&nodeType, buffer, sizeof(uint32_t));
 
 		NodePtr n;
 
@@ -1252,7 +1380,7 @@ SpatialIndex::RTree::NodePtr SpatialIndex::RTree::RTree::readNode(id_type page)
 		n->m_identifier = page;
 		n->loadFromByteArray(buffer);
 
-		++(m_stats.m_reads);
+		++(m_stats.m_u64Reads);
 
 		for (size_t cIndex = 0; cIndex < m_readNodeCommands.size(); ++cIndex)
 		{
@@ -1281,7 +1409,7 @@ void SpatialIndex::RTree::RTree::deleteNode(Node* n)
 		throw;
 	}
 
-	--(m_stats.m_nodes);
+	--(m_stats.m_u32Nodes);
 	m_stats.m_nodesInLevel[n->m_level] = m_stats.m_nodesInLevel[n->m_level] - 1;
 
 	for (size_t cIndex = 0; cIndex < m_deleteNodeCommands.size(); ++cIndex)
@@ -1292,7 +1420,7 @@ void SpatialIndex::RTree::RTree::deleteNode(Node* n)
 
 void SpatialIndex::RTree::RTree::rangeQuery(RangeQueryType type, const IShape& query, IVisitor& v)
 {
-#ifdef PTHREADS
+#ifdef HAVE_PTHREAD_H
 	Tools::SharedLock lock(&m_rwLock);
 #else
 	if (m_rwLock == false) m_rwLock = true;
@@ -1314,7 +1442,7 @@ void SpatialIndex::RTree::RTree::rangeQuery(RangeQueryType type, const IShape& q
 			{
 				v.visitNode(*n);
 
-				for (size_t cChild = 0; cChild < n->m_children; ++cChild)
+				for (uint32_t cChild = 0; cChild < n->m_children; ++cChild)
 				{
 					bool b;
 					if (type == ContainmentQuery) b = query.containsShape(*(n->m_ptrMBR[cChild]));
@@ -1324,7 +1452,7 @@ void SpatialIndex::RTree::RTree::rangeQuery(RangeQueryType type, const IShape& q
 					{
 						Data data = Data(n->m_pDataLength[cChild], n->m_pData[cChild], *(n->m_ptrMBR[cChild]), n->m_pIdentifier[cChild]);
 						v.visitData(data);
-						++(m_stats.m_queryResults);
+						++(m_stats.m_u64QueryResults);
 					}
 				}
 			}
@@ -1332,20 +1460,20 @@ void SpatialIndex::RTree::RTree::rangeQuery(RangeQueryType type, const IShape& q
 			{
 				v.visitNode(*n);
 
-				for (size_t cChild = 0; cChild < n->m_children; ++cChild)
+				for (uint32_t cChild = 0; cChild < n->m_children; ++cChild)
 				{
 					if (query.intersectsShape(*(n->m_ptrMBR[cChild]))) st.push(readNode(n->m_pIdentifier[cChild]));
 				}
 			}
 		}
 
-#ifndef PTHREADS
+#ifndef HAVE_PTHREAD_H
 		m_rwLock = false;
 #endif
 	}
 	catch (...)
 	{
-#ifndef PTHREADS
+#ifndef HAVE_PTHREAD_H
 		m_rwLock = false;
 #endif
 		throw;
@@ -1359,11 +1487,11 @@ void SpatialIndex::RTree::RTree::selfJoinQuery(id_type id1, id_type id2, const R
 	vis.visitNode(*n1);
 	vis.visitNode(*n2);
 
-	for (size_t cChild1 = 0; cChild1 < n1->m_children; ++cChild1)
+	for (uint32_t cChild1 = 0; cChild1 < n1->m_children; ++cChild1)
 	{
 		if (r.intersectsRegion(*(n1->m_ptrMBR[cChild1])))
 		{
-			for (size_t cChild2 = 0; cChild2 < n2->m_children; ++cChild2)
+			for (uint32_t cChild2 = 0; cChild2 < n2->m_children; ++cChild2)
 			{
 				if (
 					r.intersectsRegion(*(n2->m_ptrMBR[cChild2])) &&
