@@ -19,9 +19,11 @@
 //  Email:
 //    mhadji@gmail.com
 
-#include "../../include/SpatialIndex.h"
+#include <spatialindex/SpatialIndex.h>
 
 #include <cstring>
+#include <cmath>
+#include <limits>
 
 using namespace SpatialIndex;
 
@@ -30,7 +32,7 @@ Region::Region()
 {
 }
 
-Region::Region(const double* pLow, const double* pHigh, size_t dimension)
+Region::Region(const double* pLow, const double* pHigh, uint32_t dimension)
 {
 	initialize(pLow, pHigh, dimension);
 }
@@ -38,7 +40,7 @@ Region::Region(const double* pLow, const double* pHigh, size_t dimension)
 Region::Region(const Point& low, const Point& high)
 {
 	if (low.m_dimension != high.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::Region: arguments have different number of dimensions."
 		);
 
@@ -50,23 +52,23 @@ Region::Region(const Region& r)
 	initialize(r.m_pLow, r.m_pHigh, r.m_dimension);
 }
 
-void Region::initialize(const double* pLow, const double* pHigh, size_t dimension)
+void Region::initialize(const double* pLow, const double* pHigh, uint32_t dimension)
 {
 	m_pLow = 0;
 	m_dimension = dimension;
 
 #ifndef NDEBUG
-    // FIXME: this needs to be fixed for the case when both pHigh and pLow are
-    // at their numeric limits, when high can be negative infinity and low can
-    // be positive infinity
-    for (size_t cDim = 0; cDim < m_dimension; cDim++)
+    for (uint32_t cDim = 0; cDim < m_dimension; ++cDim)
     {
-     if (pLow[cDim] > pHigh[cDim])
+     if ((pLow[cDim] > pHigh[cDim]))
      {
-         throw Tools::IllegalArgumentException(
-             "Region::initialize: Low point has larger coordinates than High point. FIXME:"
-             " This produces false positives for +- infinity"
-         );
+         // check for infinitive region
+         if (!(pLow[cDim] == std::numeric_limits<double>::max() ||
+             pHigh[cDim] == -std::numeric_limits<double>::max() ))
+             throw Tools::IllegalArgumentException(
+                 "Region::initialize: Low point has larger coordinates than High point."
+                 " Neither point is infinity."
+             );
      }
     }
 #endif
@@ -107,11 +109,11 @@ Region& Region::operator=(const Region& r)
 bool Region::operator==(const Region& r) const
 {
 	if (m_dimension != r.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::operator==: Regions have different number of dimensions."
 		);
 
-	for (size_t i = 0; i < m_dimension; i++)
+	for (uint32_t i = 0; i < m_dimension; ++i)
 	{
 		if (
 			m_pLow[i] < r.m_pLow[i] - std::numeric_limits<double>::epsilon() ||
@@ -134,16 +136,16 @@ Region* Region::clone()
 //
 // ISerializable interface
 //
-size_t Region::getByteArraySize()
+uint32_t Region::getByteArraySize()
 {
-	return (sizeof(size_t) + 2 * m_dimension * sizeof(double));
+	return (sizeof(uint32_t) + 2 * m_dimension * sizeof(double));
 }
 
 void Region::loadFromByteArray(const byte* ptr)
 {
-	size_t dimension;
-	memcpy(&dimension, ptr, sizeof(size_t));
-	ptr += sizeof(size_t);
+	uint32_t dimension;
+	memcpy(&dimension, ptr, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
 
 	makeDimension(dimension);
 	memcpy(m_pLow, ptr, m_dimension * sizeof(double));
@@ -152,14 +154,14 @@ void Region::loadFromByteArray(const byte* ptr)
 	//ptr += m_dimension * sizeof(double);
 }
 
-void Region::storeToByteArray(byte** data, size_t& len)
+void Region::storeToByteArray(byte** data, uint32_t& len)
 {
 	len = getByteArraySize();
 	*data = new byte[len];
 	byte* ptr = *data;
 
-	memcpy(ptr, &m_dimension, sizeof(size_t));
-	ptr += sizeof(size_t);
+	memcpy(ptr, &m_dimension, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
 	memcpy(ptr, m_pLow, m_dimension * sizeof(double));
 	ptr += m_dimension * sizeof(double);
 	memcpy(ptr, m_pHigh, m_dimension * sizeof(double));
@@ -177,7 +179,7 @@ bool Region::intersectsShape(const IShape& s) const
 	const Point* ppt = dynamic_cast<const Point*>(&s);
 	if (ppt != 0) return containsPoint(*ppt);
 
-	throw IllegalStateException(
+	throw Tools::IllegalStateException(
 		"Region::intersectsShape: Not implemented yet!"
 	);
 }
@@ -190,7 +192,7 @@ bool Region::containsShape(const IShape& s) const
 	const Point* ppt = dynamic_cast<const Point*>(&s);
 	if (ppt != 0) return containsPoint(*ppt);
 
-	throw IllegalStateException(
+	throw Tools::IllegalStateException(
 		"Region::containsShape: Not implemented yet!"
 	);
 }
@@ -203,7 +205,7 @@ bool Region::touchesShape(const IShape& s) const
 	const Point* ppt = dynamic_cast<const Point*>(&s);
 	if (ppt != 0) return touchesPoint(*ppt);
 
-	throw IllegalStateException(
+	throw Tools::IllegalStateException(
 		"Region::touchesShape: Not implemented yet!"
 	);
 }
@@ -211,13 +213,13 @@ bool Region::touchesShape(const IShape& s) const
 void Region::getCenter(Point& out) const
 {
 	out.makeDimension(m_dimension);
-	for (size_t i = 0; i < m_dimension; i++)
+	for (uint32_t i = 0; i < m_dimension; ++i)
 	{
 		out.m_pCoords[i] = (m_pLow[i] + m_pHigh[i]) / 2.0;
 	}
 }
 
-size_t Region::getDimension() const
+uint32_t Region::getDimension() const
 {
 	return m_dimension;
 }
@@ -231,7 +233,7 @@ double Region::getArea() const
 {
 	double area = 1.0;
 
-	for (size_t i = 0; i < m_dimension; i++)
+	for (uint32_t i = 0; i < m_dimension; ++i)
 	{
 		area *= m_pHigh[i] - m_pLow[i];
 	}
@@ -247,7 +249,7 @@ double Region::getMinimumDistance(const IShape& s) const
 	const Point* ppt = dynamic_cast<const Point*>(&s);
 	if (ppt != 0) return getMinimumDistance(*ppt);
 
-	throw IllegalStateException(
+	throw Tools::IllegalStateException(
 		"Region::getMinimumDistance: Not implemented yet!"
 	);
 }
@@ -255,11 +257,11 @@ double Region::getMinimumDistance(const IShape& s) const
 bool Region::intersectsRegion(const Region& r) const
 {
 	if (m_dimension != r.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::intersectsRegion: Regions have different number of dimensions."
 		);
 
-	for (size_t i = 0; i < m_dimension; i++)
+	for (uint32_t i = 0; i < m_dimension; ++i)
 	{
 		if (m_pLow[i] > r.m_pHigh[i] || m_pHigh[i] < r.m_pLow[i]) return false;
 	}
@@ -269,11 +271,11 @@ bool Region::intersectsRegion(const Region& r) const
 bool Region::containsRegion(const Region& r) const
 {
 	if (m_dimension != r.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::containsRegion: Regions have different number of dimensions."
 		);
 
-	for (size_t i = 0; i < m_dimension; i++)
+	for (uint32_t i = 0; i < m_dimension; ++i)
 	{
 		if (m_pLow[i] > r.m_pLow[i] || m_pHigh[i] < r.m_pHigh[i]) return false;
 	}
@@ -283,32 +285,32 @@ bool Region::containsRegion(const Region& r) const
 bool Region::touchesRegion(const Region& r) const
 {
 	if (m_dimension != r.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::touchesRegion: Regions have different number of dimensions."
 		);
-
-	for (size_t i = 0; i < m_dimension; i++)
+	
+	for (uint32_t i = 0; i < m_dimension; ++i)
 	{
 		if (
-			(m_pLow[i] >= r.m_pLow[i] - std::numeric_limits<double>::epsilon() &&
-			 m_pLow[i] <= r.m_pLow[i] + std::numeric_limits<double>::epsilon()) ||
-			(m_pHigh[i] >= r.m_pHigh[i] - std::numeric_limits<double>::epsilon() &&
-			 m_pHigh[i] <= r.m_pHigh[i] + std::numeric_limits<double>::epsilon()))
-			return true;
+			(m_pLow[i] >= r.m_pLow[i] + std::numeric_limits<double>::epsilon() &&
+			m_pLow[i] <= r.m_pLow[i] - std::numeric_limits<double>::epsilon()) ||
+			(m_pHigh[i] >= r.m_pHigh[i] + std::numeric_limits<double>::epsilon() &&
+			m_pHigh[i] <= r.m_pHigh[i] - std::numeric_limits<double>::epsilon()))
+			return false;
 	}
-	return false;
+	return true;
 }
 
 double Region::getMinimumDistance(const Region& r) const
 {
 	if (m_dimension != r.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::getMinimumDistance: Regions have different number of dimensions."
 		);
 
 	double ret = 0.0;
 
-	for (size_t i = 0; i < m_dimension; i++)
+	for (uint32_t i = 0; i < m_dimension; ++i)
 	{
 		double x = 0.0;
 
@@ -330,11 +332,11 @@ double Region::getMinimumDistance(const Region& r) const
 bool Region::containsPoint(const Point& p) const
 {
 	if (m_dimension != p.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::containsPoint: Point has different number of dimensions."
 		);
 
-	for (size_t i = 0; i < m_dimension; i++)
+	for (uint32_t i = 0; i < m_dimension; ++i)
 	{
 		if (m_pLow[i] > p.getCoordinate(i) || m_pHigh[i] < p.getCoordinate(i)) return false;
 	}
@@ -344,11 +346,11 @@ bool Region::containsPoint(const Point& p) const
 bool Region::touchesPoint(const Point& p) const
 {
 	if (m_dimension != p.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::touchesPoint: Point has different number of dimensions."
 		);
 
-	for (size_t i = 0; i < m_dimension; i++)
+	for (uint32_t i = 0; i < m_dimension; ++i)
 	{
 		if (
 			(m_pLow[i] >= p.getCoordinate(i) - std::numeric_limits<double>::epsilon() &&
@@ -363,13 +365,13 @@ bool Region::touchesPoint(const Point& p) const
 double Region::getMinimumDistance(const Point& p) const
 {
 	if (m_dimension != p.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::getMinimumDistance: Point has different number of dimensions."
 		);
 
 	double ret = 0.0;
 
-	for (size_t i = 0; i < m_dimension; i++)
+	for (uint32_t i = 0; i < m_dimension; ++i)
 	{
 		if (p.getCoordinate(i) < m_pLow[i])
 		{
@@ -387,7 +389,7 @@ double Region::getMinimumDistance(const Point& p) const
 Region Region::getIntersectingRegion(const Region& r) const
 {
 	if (m_dimension != r.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::getIntersectingRegion: Regions have different number of dimensions."
 		);
 
@@ -396,12 +398,12 @@ Region Region::getIntersectingRegion(const Region& r) const
 
 	// check for intersection.
 	// marioh: avoid function call since this is called billions of times.
-	for (size_t cDim = 0; cDim < m_dimension; cDim++)
+	for (uint32_t cDim = 0; cDim < m_dimension; ++cDim)
 	{
 		if (m_pLow[cDim] > r.m_pHigh[cDim] || m_pHigh[cDim] < r.m_pLow[cDim]) return ret;
 	}
 
-	for (size_t cDim = 0; cDim < m_dimension; cDim++)
+	for (uint32_t cDim = 0; cDim < m_dimension; ++cDim)
 	{
 		ret.m_pLow[cDim] = std::max(m_pLow[cDim], r.m_pLow[cDim]);
 		ret.m_pHigh[cDim] = std::min(m_pHigh[cDim], r.m_pHigh[cDim]);
@@ -413,14 +415,14 @@ Region Region::getIntersectingRegion(const Region& r) const
 double Region::getIntersectingArea(const Region& r) const
 {
 	if (m_dimension != r.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::getIntersectingArea: Regions have different number of dimensions."
 		);
 
 	double ret = 1.0;
 	double f1, f2;
 
-	for (size_t cDim = 0; cDim < m_dimension; cDim++)
+	for (uint32_t cDim = 0; cDim < m_dimension; ++cDim)
 	{
 		if (m_pLow[cDim] > r.m_pHigh[cDim] || m_pHigh[cDim] < r.m_pLow[cDim]) return 0.0;
 
@@ -441,7 +443,7 @@ double Region::getMargin() const
 	double mul = std::pow(2.0, static_cast<double>(m_dimension) - 1.0);
 	double margin = 0.0;
 
-	for (size_t i = 0; i < m_dimension; i++)
+	for (uint32_t i = 0; i < m_dimension; ++i)
 	{
 		margin += (m_pHigh[i] - m_pLow[i]) * mul;
 	}
@@ -452,11 +454,11 @@ double Region::getMargin() const
 void Region::combineRegion(const Region& r)
 {
 	if (m_dimension != r.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::combineRegion: Region has different number of dimensions."
 		);
 
-	for (size_t cDim = 0; cDim < m_dimension; cDim++)
+	for (uint32_t cDim = 0; cDim < m_dimension; ++cDim)
 	{
 		m_pLow[cDim] = std::min(m_pLow[cDim], r.m_pLow[cDim]);
 		m_pHigh[cDim] = std::max(m_pHigh[cDim], r.m_pHigh[cDim]);
@@ -466,11 +468,11 @@ void Region::combineRegion(const Region& r)
 void Region::combinePoint(const Point& p)
 {
 	if (m_dimension != p.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::combinePoint: Point has different number of dimensions."
 		);
 
-	for (size_t cDim = 0; cDim < m_dimension; cDim++)
+	for (uint32_t cDim = 0; cDim < m_dimension; ++cDim)
 	{
 		m_pLow[cDim] = std::min(m_pLow[cDim], p.m_pCoords[cDim]);
 		m_pHigh[cDim] = std::max(m_pHigh[cDim], p.m_pCoords[cDim]);
@@ -480,7 +482,7 @@ void Region::combinePoint(const Point& p)
 void Region::getCombinedRegion(Region& out, const Region& in) const
 {
 	if (m_dimension != in.m_dimension)
-		throw IllegalArgumentException(
+		throw Tools::IllegalArgumentException(
 			"Region::getCombinedRegion: Regions have different number of dimensions."
 		);
 
@@ -488,33 +490,33 @@ void Region::getCombinedRegion(Region& out, const Region& in) const
 	out.combineRegion(in);
 }
 
-double Region::getLow(size_t index) const
+double Region::getLow(uint32_t index) const
 {
-	if (index < 0 || index >= m_dimension)
-		throw IndexOutOfBoundsException(index);
+	if (index >= m_dimension)
+		throw Tools::IndexOutOfBoundsException(index);
 
 	return m_pLow[index];
 }
 
-double Region::getHigh(size_t index) const
+double Region::getHigh(uint32_t index) const
 {
-	if (index < 0 || index >= m_dimension)
-		throw IndexOutOfBoundsException(index);
+	if (index >= m_dimension)
+		throw Tools::IndexOutOfBoundsException(index);
 
 	return m_pHigh[index];
 }
 
-void Region::makeInfinite(size_t dimension)
+void Region::makeInfinite(uint32_t dimension)
 {
 	makeDimension(dimension);
-	for (size_t cIndex = 0; cIndex < m_dimension; cIndex++)
+	for (uint32_t cIndex = 0; cIndex < m_dimension; ++cIndex)
 	{
 		m_pLow[cIndex] = std::numeric_limits<double>::max();
 		m_pHigh[cIndex] = -std::numeric_limits<double>::max();
 	}
 }
 
-void Region::makeDimension(size_t dimension)
+void Region::makeDimension(uint32_t dimension)
 {
 	if (m_dimension != dimension)
 	{
@@ -533,17 +535,17 @@ void Region::makeDimension(size_t dimension)
 
 std::ostream& SpatialIndex::operator<<(std::ostream& os, const Region& r)
 {
-	size_t i;
+	uint32_t i;
 
 	os << "Low: ";
-	for (i = 0; i < r.m_dimension; i++)
+	for (i = 0; i < r.m_dimension; ++i)
 	{
 		os << r.m_pLow[i] << " ";
 	}
 
 	os << ", High: ";
 
-	for (i = 0; i < r.m_dimension; i++)
+	for (i = 0; i < r.m_dimension; ++i)
 	{
 		os << r.m_pHigh[i] << " ";
 	}
