@@ -20,8 +20,12 @@
 //    mhadji@gmail.com
 
 #include <time.h>
-#include "../../include/tools/Tools.h"
-#include "../../include/tools/rand48.h"
+#include <limits>
+#include <spatialindex/tools/Tools.h>
+
+#ifndef HAVE_SRAND48
+#include <spatialindex/tools/rand48.h>
+#endif
 
 #include <cstring>
 
@@ -88,20 +92,40 @@ Tools::Variant::Variant() : m_varType(VT_EMPTY)
 
 Tools::PropertySet::PropertySet(const byte* data)
 {
+#ifdef HAVE_PTHREAD_H
+	// pthread_rwlock_init(&m_rwLock, NULL);
+#else
+	m_rwLock = false;
+#endif
 	loadFromByteArray(data);
 }
 
+Tools::PropertySet::~PropertySet() 
+{
+#ifdef HAVE_PTHREAD_H
+	// pthread_rwlock_destroy(&m_rwLock);
+#endif	
+}
+
+Tools::PropertySet::PropertySet()
+{
+#ifdef HAVE_PTHREAD_H
+	// pthread_rwlock_init(&m_rwLock, NULL);
+#else
+	m_rwLock = false;
+#endif	
+}
 void Tools::PropertySet::loadFromByteArray(const byte* ptr)
 {
 	m_propertySet.clear();
 
-	size_t numberOfProperties;
-	memcpy(&numberOfProperties, ptr, sizeof(size_t));
-	ptr += sizeof(size_t);
+	uint32_t numberOfProperties;
+	memcpy(&numberOfProperties, ptr, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
 
 	Variant v;
 
-	for (size_t cIndex = 0; cIndex < numberOfProperties; cIndex++)
+	for (uint32_t cIndex = 0; cIndex < numberOfProperties; ++cIndex)
 	{
 		std::string s(reinterpret_cast<const char*>(ptr));
 		ptr += s.size() + 1;
@@ -186,12 +210,12 @@ void Tools::PropertySet::loadFromByteArray(const byte* ptr)
 	}
 }
 
-size_t Tools::PropertySet::getByteArraySize()
+uint32_t Tools::PropertySet::getByteArraySize()
 {
-	size_t size = sizeof(size_t);
+	uint32_t size = sizeof(uint32_t);
 	std::map<std::string, Variant>::iterator it;
 
-	for (it = m_propertySet.begin(); it != m_propertySet.end(); it++)
+	for (it = m_propertySet.begin(); it != m_propertySet.end(); ++it)
 	{
 		switch ((*it).second.m_varType)
 		{
@@ -233,31 +257,31 @@ size_t Tools::PropertySet::getByteArraySize()
 				"Tools::PropertySet::getSize: Unknown type."
 			);
 		}
-		size += (*it).first.size() + 1 + sizeof(VariantType);
+		size += static_cast<uint32_t>((*it).first.size()) + 1 + sizeof(VariantType);
 	}
 
 	return size;
 }
 
-void Tools::PropertySet::storeToByteArray(byte** data, size_t& length)
+void Tools::PropertySet::storeToByteArray(byte** data, uint32_t& length)
 {
 	length = getByteArraySize();
 	*data = new byte[length];
 	byte* ptr = *data;
 
-	size_t numberOfProperties = m_propertySet.size();
-	memcpy(ptr, &numberOfProperties, sizeof(size_t));
-	ptr += sizeof(size_t);
+	uint32_t numberOfProperties = static_cast<uint32_t>(m_propertySet.size());
+	memcpy(ptr, &numberOfProperties, sizeof(uint32_t));
+	ptr += sizeof(uint32_t);
 
 	std::map<std::string, Variant>::iterator it;
 
-	for (it = m_propertySet.begin(); it != m_propertySet.end(); it++)
+	for (it = m_propertySet.begin(); it != m_propertySet.end(); ++it)
 	{
 		size_t strSize = (*it).first.size();
 		memcpy(ptr, (*it).first.c_str(), strSize);
 		ptr += strSize;
 		*ptr = 0;
-		ptr++;
+		++ptr;
 
 		memcpy(ptr, &((*it).second.m_varType), sizeof(VariantType));
 		ptr += sizeof(VariantType);
@@ -322,28 +346,89 @@ void Tools::PropertySet::storeToByteArray(byte** data, size_t& length)
 
 Tools::Variant Tools::PropertySet::getProperty(std::string property)
 {
-	std::map<std::string, Variant>::iterator it = m_propertySet.find(property);
+// #ifdef HAVE_PTHREAD_H
+//     Tools::ExclusiveLock lock(&m_rwLock);
+// #else
+// 	if (m_rwLock == false) m_rwLock = true;
+// 	else throw Tools::IllegalStateException("getProperty: cannot acquire an shared lock");
+// #endif
 
-	if (it != m_propertySet.end()) return (*it).second;
-	else return Variant();
+	try
+	{
+    	std::map<std::string, Variant>::iterator it = m_propertySet.find(property);
+
+    	if (it != m_propertySet.end()) return (*it).second;
+    	else return Variant();
+	
+#ifndef HAVE_PTHREAD_H
+		m_rwLock = false;
+#endif
+
+	}
+	catch (...)
+	{
+#ifndef HAVE_PTHREAD_H
+		m_rwLock = false;
+#endif
+		throw;
+	}
 }
 
 void Tools::PropertySet::setProperty(std::string property, Variant& v)
 {
-	std::pair<std::map<std::string, Variant>::iterator, bool> ret;
-	std::map<std::string, Variant>::iterator it;
-	
-	ret = m_propertySet.insert(std::pair<std::string, Variant>(property, v));
+#ifdef HAVE_PTHREAD_H
+	// Tools::ExclusiveLock lock(&m_rwLock);
+#else
+	if (m_rwLock == false) m_rwLock = true;
+	else throw Tools::EndOfStreamException("setProperty: cannot acquire an exclusive lock");
+#endif
 
-	// If we weren't able to insert because it is already in the map
-	// update our existing value
-	if (ret.second == false) ret.first->second = v;
+	try
+	{
+    	std::pair<std::map<std::string, Variant>::iterator, bool> ret;
+    	std::map<std::string, Variant>::iterator it;
+	
+    	ret = m_propertySet.insert(std::pair<std::string, Variant>(property, v));
+
+    	// If we weren't able to insert because it is already in the map
+    	// update our existing value
+    	if (ret.second == false) ret.first->second = v;
+
+#ifndef HAVE_PTHREAD_H
+		m_rwLock = false;
+#endif
+
+	}
+	catch (...)
+	{
+#ifndef HAVE_PTHREAD_H
+		m_rwLock = false;
+#endif
+		throw;
+	}
 }
 
 void Tools::PropertySet::removeProperty(std::string property)
 {
-	std::map<std::string, Variant>::iterator it = m_propertySet.find(property);
-	if (it != m_propertySet.end()) m_propertySet.erase(it);
+#ifdef HAVE_PTHREAD_H
+	// Tools::ExclusiveLock lock(&m_rwLock);
+#else
+	if (m_rwLock == false) m_rwLock = true;
+	else throw Tools::EndOfStreamException("setProperty: cannot acquire an exclusive lock");
+#endif
+
+	try
+	{
+	   	std::map<std::string, Variant>::iterator it = m_propertySet.find(property);
+	   	if (it != m_propertySet.end()) m_propertySet.erase(it);
+	}
+	catch (...)
+	{
+#ifndef HAVE_PTHREAD_H
+		m_rwLock = false;
+#endif
+		throw;
+	}
 }
 
 Tools::Interval::Interval() : m_type(IT_RIGHTOPEN), m_low(0.0), m_high(0.0)
@@ -519,7 +604,7 @@ Tools::IntervalType Tools::Interval::getIntervalType() const
 Tools::Random::Random()
 {
 	m_pBuffer = 0;
-	initDrand(time(0), 0xD31A);
+	initDrand(static_cast<uint32_t>(time(0)), 0xD31A);
 }
 
 Tools::Random::Random(uint32_t seed, uint16_t xsubi0)
@@ -650,7 +735,7 @@ std::ostream& Tools::operator<<(std::ostream& os, const Tools::PropertySet& p)
 {
 	std::map<std::string, Variant>::const_iterator it;
 
-	for (it = p.m_propertySet.begin(); it != p.m_propertySet.end(); it++)
+	for (it = p.m_propertySet.begin(); it != p.m_propertySet.end(); ++it)
 	{
 		if (it != p.m_propertySet.begin()) os << ", ";
 
@@ -715,8 +800,8 @@ std::ostream& Tools::operator<<(std::ostream& os, const Tools::Interval& iv)
 //
 // BufferedFile
 //
-Tools::BufferedFile::BufferedFile(size_t stBufferSize)
-: m_buffer(new char[stBufferSize]), m_stBufferSize(stBufferSize), m_bEOF(true)
+Tools::BufferedFile::BufferedFile(uint32_t u32BufferSize)
+: m_buffer(new char[u32BufferSize]), m_u32BufferSize(u32BufferSize), m_bEOF(true)
 {
 }
 
@@ -743,8 +828,8 @@ Tools::BufferedFileReader::BufferedFileReader()
 {
 }
 
-Tools::BufferedFileReader::BufferedFileReader(const std::string& sFileName, size_t stBufferSize)
-: BufferedFile(stBufferSize)
+Tools::BufferedFileReader::BufferedFileReader(const std::string& sFileName, uint32_t u32BufferSize)
+: BufferedFile(u32BufferSize)
 {
 	open(sFileName);
 }
@@ -759,7 +844,7 @@ void Tools::BufferedFileReader::open(const std::string& sFileName)
 	if (! m_file.good())
 		throw std::ios_base::failure("Tools::BufferedFileReader::BufferedFileReader: Cannot open file.");
 
-	m_file.rdbuf()->pubsetbuf(m_buffer, m_stBufferSize);
+	m_file.rdbuf()->pubsetbuf(m_buffer, m_u32BufferSize);
 }
 
 Tools::BufferedFileReader::~BufferedFileReader()
@@ -887,8 +972,8 @@ std::string Tools::BufferedFileReader::readString()
 {
 	if (m_bEOF) throw Tools::EndOfStreamException("");
 
-	std::string::size_type len;
-	m_file.read(reinterpret_cast<char*>(&len), sizeof(std::string::size_type));
+	uint32_t len;
+	m_file.read(reinterpret_cast<char*>(&len), sizeof(uint32_t));
 	if (! m_file.good())
 	{
 		m_bEOF = true;
@@ -932,8 +1017,8 @@ Tools::BufferedFileWriter::BufferedFileWriter()
 	open("");
 }
 
-Tools::BufferedFileWriter::BufferedFileWriter(const std::string& sFileName, FileMode mode, size_t stBufferSize)
-: BufferedFile(stBufferSize)
+Tools::BufferedFileWriter::BufferedFileWriter(const std::string& sFileName, FileMode mode, uint32_t u32BufferSize)
+: BufferedFile(u32BufferSize)
 {
 	open(sFileName, mode);
 }
@@ -1041,8 +1126,8 @@ void Tools::BufferedFileWriter::write(bool b)
 
 void Tools::BufferedFileWriter::write(const std::string& s)
 {
-	std::string::size_type len = s.size();
-	m_file.write(reinterpret_cast<const char*>(&len), sizeof(std::string::size_type));
+	uint32_t len = static_cast<uint32_t>(s.size());
+	m_file.write(reinterpret_cast<const char*>(&len), sizeof(uint32_t));
 	if (! m_file.good()) throw std::ios_base::failure("");
 	m_file.write(reinterpret_cast<const char*>(s.c_str()), len * sizeof(std::string::value_type));
 	if (! m_file.good()) throw std::ios_base::failure("");
@@ -1059,16 +1144,30 @@ void Tools::BufferedFileWriter::write(uint32_t u32Len, byte* pData)
 //
 Tools::TemporaryFile::TemporaryFile()
 {
+    
 #ifdef _MSC_VER
+
+#ifndef L_tmpnam_s
+// MSVC 2003 doesn't have tmpnam_s, so we'll have to use the old functions
+
+    char* tmpName = NULL;
+    tmpName = tmpnam( NULL );
+    
+    if (tmpName == NULL)
+        throw std::ios_base::failure("Tools::TemporaryFile: Cannot create temporary file name.");
+     
+#else 
 	char tmpName[L_tmpnam_s];
 	errno_t err = tmpnam_s(tmpName, L_tmpnam_s);
 	if (err)
 		throw std::ios_base::failure("Tools::TemporaryFile: Cannot create temporary file name.");
 
+#endif
 	if (tmpName[0] == '\\')
 		m_sFile = std::string(tmpName + 1);
 	else
 		m_sFile = std::string(tmpName);
+
 #else
 	char tmpName[7] = "XXXXXX";
 	if (mktemp(tmpName) == 0)
