@@ -60,7 +60,7 @@ namespace SpatialIndex
 			//
 			// ISpatialIndex interface
 			//
-			virtual void insertData(size_t len, const byte* pData, const IShape& shape, id_type shapeIdentifier);
+			virtual void insertData(uint32_t len, const byte* pData, const IShape& shape, id_type shapeIdentifier);
 			virtual bool deleteData(const IShape& shape, id_type id);
 			virtual void containsWhatQuery(const IShape& query, IVisitor& v);
 			virtual void intersectsWithQuery(const IShape& query, IVisitor& v);
@@ -80,8 +80,8 @@ namespace SpatialIndex
 			void storeHeader();
 			void loadHeader();
 
-			void insertData_impl(size_t dataLength, byte* pData, MovingRegion& mbr, id_type id);
-			void insertData_impl(size_t dataLength, byte* pData, MovingRegion& mbr, id_type id, size_t level, byte* overflowTable);
+			void insertData_impl(uint32_t dataLength, byte* pData, MovingRegion& mbr, id_type id);
+			void insertData_impl(uint32_t dataLength, byte* pData, MovingRegion& mbr, id_type id, uint32_t level, byte* overflowTable);
 			bool deleteData_impl(const MovingRegion& mbr, id_type id);
 
 			id_type writeNode(Node*);
@@ -98,11 +98,11 @@ namespace SpatialIndex
 
 			double m_fillFactor;
 
-			size_t m_indexCapacity;
+			uint32_t m_indexCapacity;
 
-			size_t m_leafCapacity;
+			uint32_t m_leafCapacity;
 
-			size_t m_nearMinimumOverlapFactor;
+			uint32_t m_nearMinimumOverlapFactor;
 				// The R*-Tree 'p' constant, for calculating nearly minimum overlap cost.
 				// [Beckmann, Kriegel, Schneider, Seeger 'The R*-tree: An efficient and Robust Access Method
 				// for Points and Rectangles', Section 4.1]
@@ -117,7 +117,7 @@ namespace SpatialIndex
 				// [Beckmann, Kriegel, Schneider, Seeger 'The R*-tree: An efficient and Robust Access Method
 				//  for Points and Rectangles', Section 4.3]
 
-			size_t m_dimension;
+			uint32_t m_dimension;
 
 			MovingRegion m_infiniteRegion;
 
@@ -138,7 +138,7 @@ namespace SpatialIndex
 			std::vector<Tools::SmartPointer<ICommand> > m_readNodeCommands;
 			std::vector<Tools::SmartPointer<ICommand> > m_deleteNodeCommands;
 
-#ifdef PTHREADS
+#ifdef HAVE_PTHREAD_H
 			pthread_rwlock_t m_rwLock;
 #else
 			bool m_rwLock;
